# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pybet', 'pybet.staking']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'pybet',
    'version': '0.4.1',
    'description': 'A library of betting utilities to assist with calculation of bets, stakes and markets',
    'long_description': '[![PyPI](https://img.shields.io/pypi/v/pybet.svg?style=for-the-badge)](https://pypi.org/project/pybet/)\n[![docs: passing](https://readthedocs.org/projects/tabletoppy/badge/?version=latest)](https://pybet.readthedocs.io/en/latest/?badge=latest)\n[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\n# pybet\n\npybet is a library of betting utilities to assist with calculation of bets, stakes and markets\n\n## Installation\n\n`pip install pybet`\n\nor\n\n`poetry add pybet`\n',
    'author': 'Robert Peacock',
    'author_email': 'robertjamespeacock@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/peaky76/pybet',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.9.0,<4.0.0',
}


setup(**setup_kwargs)



from __future__ import annotations
from decimal import Decimal
from ..odds import Odds


def kelly(true_odds: Odds, market_odds: Odds, bank: Decimal) -> Decimal:
    """Calculates the stake that should be placed according to the Kelly Criterion
    [https://en.wikipedia.org/wiki/Kelly_criterion], i.e. edge over odds
    for any given true odds at any given market odds for any given bank size

    :param true_odds: The calculated true odds of the selection
    :type true_odds: Odds
    :param market_odds: The odds currently available in the market
    :type market_odds: Odds
    :param bank: The bank available
    :type bank: Decimal
    :return: The stake to place according to the Kelly criterion
    :rtype: Decimal


    :Example:
        >>> kelly(Odds(4), Odds(5), 100)
        Decimal('6.25')
        >>> kelly(Odds(5), Odds(4), 100)
        Decimal('0.00')
    """

    p = true_odds.to_probability()
    q = 1 - p
    b = market_odds.to_one()

    kelly_percentage = (b * p - q) / b
    stake = round(
        (Decimal(bank * kelly_percentage) if kelly_percentage > 0.0 else Decimal(0.00)),
        2,
    )

    return stake
